/// <reference types="node" />
import * as events from 'events';
import * as lsProtocol from 'vscode-languageserver-protocol';
import { ILspConnection, ILspOptions, IPosition, ITokenInfo } from './types';
declare class LspWsConnection extends events.EventEmitter implements ILspConnection {
    private isConnected;
    private socket;
    private documentInfo;
    private serverCapabilities;
    private documentVersion;
    private connection;
    constructor(options: ILspOptions);
    /**
     * Initialize a connection over a web socket that speaks the LSP protocol
     */
    connect(socket: WebSocket): this;
    sendInitialize(): void;
    sendChange(): void;
    getHoverTooltip(location: IPosition): void;
    getCompletion(location: IPosition, token: ITokenInfo, triggerCharacter?: string, triggerKind?: lsProtocol.CompletionTriggerKind): void;
    getDetailedCompletion(completionItem: lsProtocol.CompletionItem): void;
    getSignatureHelp(location: IPosition): void;
    /**
     * Request the locations of all matching document symbols
     */
    getDocumentHighlights(location: IPosition): void;
    /**
     * The characters that trigger completion automatically.
     */
    getLanguageCompletionCharacters(): string[];
    /**
     * The characters that trigger signature help automatically.
     */
    getLanguageSignatureCharacters(): string[];
}
export default LspWsConnection;
